django_analyses.filters.input package — django_analyses 0.0.3 documentation

# django_analyses.filters.input package

## Submodules

## django_analyses.filters.input.input module

class `django_analyses.filters.input.input.` `InputFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `Input` model.

  class `Meta`

    Bases: `object`

    `fields` = ('run',)
    `model`

      alias of `django_analyses.models.input.input.Input`

  `base_filters` = {'run': <django_filters.filters.ModelChoiceFilter object>}
  `declared_filters` = {}

## django_analyses.filters.input.input_definition module

class `django_analyses.filters.input.input_definition.` `InputDefinitionFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `InputDefinition` model.

  class `Meta`

    Bases: `object`

    `fields` = ('key', 'required', 'is_configuration', 'input_specification')
    `model`

      alias of `django_analyses.models.input.definitions.input_definition.InputDefinition`

  `base_filters` = {'input_specification': <django_filters.filters.AllValuesFilter object>, 'is_configuration': <django_filters.rest_framework.filters.BooleanFilter object>, 'key': <django_filters.filters.CharFilter object>, 'required': <django_filters.rest_framework.filters.BooleanFilter object>}
  `declared_filters` = {'input_specification': <django_filters.filters.AllValuesFilter object>}

class `django_analyses.filters.input.input_definition.` `NumberInFilter`(*args, **kwargs)

  Bases: `django_filters.filters.BaseInFilter`, `django_filters.filters.NumberFilter`

## Module contents